@@ -1,3 +1,4 @@
+from trame import state
 from trame.internal.app import get_app_instance
 from trame.html import AbstractElement
 
@@ -186,8 +187,10 @@ class VtkRemoteLocalView(AbstractElement):
         __ns = kwargs.get("namespace", "view")
         self.__mode_key = f"{__ns}Mode"
         self.__scene_id = f"{__ns}Scene"
+        self.__view_key_id = f"{__ns}Id"
         self.__ref = kwargs.get("ref", __ns)
         self.__rendering = enable_rendering
+        self.__namespace = __ns
 
         # !!! HACK !!!
         # Allow user to configure view mode by providing (..., local/remote) and or "local/remote"
@@ -205,20 +208,21 @@ class VtkRemoteLocalView(AbstractElement):
         self._attributes["mode"] = f':mode="{__mode_expression}"'
         # !!! HACK !!!
 
-        self.__view_id = MODULE.id(view)
+        state[self.__view_key_id] = MODULE.id(view)
         self.__view = view
         self.__wrapped_view = MODULE.view(view, name=__ns, mode=__mode_start)
 
         # Provide mandatory attributes
         self._attributes["wsClient"] = ':wsClient="wsClient"'
         self._attributes["ref"] = f'ref="{self.__ref}"'
-        self._attributes["view_id"] = f'id="{self.__view_id}"'
+        self._attributes["view_id"] = f':id="{self.__view_key_id}"'
         self._attributes["view_state"] = f':viewState="{self.__scene_id}"'
         self._attributes["namespace"] = f'namespace="{__ns}"'
 
         self._attr_names += [
             # "mode", # <--- Managed by hand above
             "context_name",
+            "interactive_quality",
             "interactive_ratio",
             "interactor_events",
             "interactor_settings",
@@ -229,33 +233,44 @@ class VtkRemoteLocalView(AbstractElement):
             ("box_selection_change", "BoxSelection"),
         ]
 
-    def update_geometry(self):
+    def update_geometry(self, reset_camera=False):
         """
         Force update to geometry
         """
-        self.__app.set(self.__scene_id, MODULE.scene(self.__view))
+        self.__app.set(self.__scene_id, MODULE.scene(self.__view, reset_camera))
 
-    def update_image(self):
+    def update_image(self, reset_camera=False):
         """
         Force update to image
         """
-        MODULE.push_image(self.__view)
+        MODULE.push_image(self.__view, reset_camera)
 
-    def set_local_rendering(self, local=True):
+    def set_local_rendering(self, local=True, **kwargs):
         self.__app.set(self.__mode_key, "local" if local else "remote")
 
-    def set_remote_rendering(self, remote=True):
+    def set_remote_rendering(self, remote=True, **kwargs):
         self.__app.set(self.__mode_key, "remote" if remote else "local")
 
-    def update(self):
+    def update(self, reset_camera=False, **kwargs):
         # need to do both to keep things in sync
         if self.__rendering:
-            self.update_image()
-        self.update_geometry()
+            self.update_image(reset_camera)
+        self.update_geometry(reset_camera)
 
-    def reset_camera(self):
+    def replace_view(self, new_view, **kwargs):
+        state[self.__view_key_id] = MODULE.id(new_view)
+        _mode = state[self.__mode_key]
+        self.__view = new_view
+        self.__wrapped_view = MODULE.view(new_view, name=self.__namespace, mode=_mode, force_replace=True)
+        self.update()
+        self.resize()
+
+    def reset_camera(self, **kwargs):
         self.__app.update(ref=self.__ref, method="resetCamera")
 
+    def resize(self, **kwargs):
+        self.__app.update(ref=self.__ref, method="resize")
+
     @property
     def view(self):
         """
@@ -298,9 +313,11 @@ class VtkRemoteView(AbstractElement):
         self.__app = get_app_instance()
         self.__view = view
         self.__ref = ref
+        self.__view_key_id = f"{ref}Id"
+        state[self.__view_key_id] = MODULE.id(view)
         self._attributes["wsClient"] = ':wsClient="wsClient"'
         self._attributes["ref"] = f'ref="{ref}"'
-        self._attributes["view_id"] = f'id="{MODULE.id(view)}"'
+        self._attributes["view_id"] = f':id="{self.__view_key_id}"'
         self._attr_names += [
             "enable_picking",
             "interactive_quality",
@@ -313,15 +330,23 @@ class VtkRemoteView(AbstractElement):
             ("box_selection_change", "BoxSelection"),
         ]
 
-    def update(self):
+    def update(self, **kwargs):
         """
         Force image to be pushed to client
         """
         MODULE.push_image(self.__view)
 
-    def reset_camera(self):
+    def reset_camera(self, **kwargs):
         self.__app.update(ref=self.__ref, method="resetCamera")
 
+    def replace_view(self, new_view, **kwargs):
+        self.__view = new_view
+        state[self.__view_key_id] = MODULE.id(new_view)
+        self.update()
+        self.resize()
+
+    def resize(self, **kwargs):
+        self.__app.update(ref=self.__ref, method="resize")
 
 class VtkShareDataset(AbstractElement):
     def __init__(self, children=None, **kwargs):
@@ -371,20 +396,28 @@ class VtkLocalView(AbstractElement):
         ]
         self.update()
 
-    def update(self):
+    def update(self, **kwargs):
         """
         Force geometry to be pushed
         """
         _app = get_app_instance()
         _app.set(self.__scene_id, MODULE.scene(self.__view))
 
-    def reset_camera(self):
+    def reset_camera(self, **kwargs):
         """
         Move camera to center actors within the frame
         """
         _app = get_app_instance()
         _app.update(ref=self.__ref, method="resetCamera")
 
+    def replace_view(self, new_view, **kwargs):
+        self.__view = new_view
+        self.__app.update(ref=self.__ref, method="setSynchronizedViewId", args=f"[{MODULE.id(new_view)}]")
+        self.update()
+
+    def resize(self, **kwargs):
+        self.__app.update(ref=self.__ref, method="resize")
+
 
 class VtkView(AbstractElement):
     def __init__(self, children=None, ref="view", **kwargs):
@@ -405,7 +438,7 @@ class VtkView(AbstractElement):
             "resize",
         ]
 
-    def reset_camera(self):
+    def reset_camera(self, **kwargs):
         """
         Move camera to center actors within the frame
         """
